#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-th
version:              0.4.3.10
visibility:           public
id:                   microlens-th-0.4.3.10-GVZ6EGiYS4v3NlzLu2dM4I
key:                  microlens-th-0.4.3.10-GVZ6EGiYS4v3NlzLu2dM4I
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Eric Mertens, Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             Automatic generation of record lenses for microlens
description:
    This package lets you automatically generate lenses for data types; code was extracted from the lens package, and therefore generated lenses are fully compatible with ones generated by lens (and can be used both from lens and microlens).

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  0a23c3d1162fd07089ecd1818fd7dde2
exposed:              True
exposed-modules:      Lens.Micro.TH Lens.Micro.TH.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/microlens-th-0.4.3.10
library-dirs:         /usr/lib/ghc-8.10.5/site-local/microlens-th-0.4.3.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/microlens-th-0.4.3.10
hs-libraries:         HSmicrolens-th-0.4.3.10-GVZ6EGiYS4v3NlzLu2dM4I
depends:
    base-4.14.2.0 containers-0.6.4.1
    microlens-0.4.12.0-7mbtYeVEJj9DE2AV66WaoK template-haskell-2.16.0.0
    th-abstraction-0.4.3.0-5HX1AugCZKLKm3ZYKErCAM transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-th/html/microlens-th.haddock

haddock-html:         /usr/share/doc/haskell-microlens-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

